// Audio context setup
const audioContext = new (window.AudioContext || window.webkitAudioContext)();
let isPlaying = false;
let currentBPM = 120;
let tracks = [];

// DOM elements
const playBtn = document.getElementById('playBtn');
const stopBtn = document.getElementById('stopBtn');
const bpmControl = document.getElementById('bpmControl');
const bpmValue = document.getElementById('bpmValue');
const tracksContainer = document.getElementById('tracksContainer');
const timeline = document.getElementById('timeline');
const masterVolume = document.getElementById('masterVolume');
const masterMeter = document.getElementById('masterMeter');
const newProjectBtn = document.getElementById('newProjectBtn');
const saveProjectBtn = document.getElementById('saveProjectBtn');
const exportBtn = document.getElementById('exportBtn');
const generateChordsBtn = document.getElementById('generateChordsBtn');
const generateMelodyBtn = document.getElementById('generateMelodyBtn');
const aiStyleSelect = document.getElementById('aiStyleSelect');

// Initialize
function init() {
  createDefaultTracks();
  setupEventListeners();
  updateMeter();
}

function createDefaultTracks() {
  const trackTypes = ['Drum', 'Bass', 'Piano', 'Synth', 'Vocals'];
  
  trackTypes.forEach((type, index) => {
    const track = {
      id: `track-${index}`,
      name: `${type} Track`,
      muted: false,
      solo: false,
      volume: 80,
      pan: 0,
      clips: []
    };
    
    tracks.push(track);
    renderTrack(track);
  });
}

function renderTrack(track) {
  const trackElement = document.createElement('div');
  trackElement.className = 'track';
  trackElement.id = track.id;
  trackElement.innerHTML = `
    <div class="track-name">${track.name}</div>
    <div class="track-controls">
      <input type="checkbox" ${track.muted ? 'checked' : ''}>
    </div>
    <div class="track-controls">
      <input type="checkbox" ${track.solo ? 'checked' : ''}>
    </div>
    <div class="track-controls">
      <input type="range" min="0" max="100" value="${track.volume}">
    </div>
    <div class="track-controls">
      <input type="range" min="-100" max="100" value="${track.pan}">
    </div>
    <div class="track-controls">
      <button>FX</button>
    </div>
  `;
  
  tracksContainer.appendChild(trackElement);
}

function setupEventListeners() {
  playBtn.addEventListener('click', togglePlayback);
  stopBtn.addEventListener('click', stopPlayback);
  bpmControl.addEventListener('input', updateBPM);
  masterVolume.addEventListener('input', updateMasterVolume);
  newProjectBtn.addEventListener('click', newProject);
  saveProjectBtn.addEventListener('click', saveProject);
  exportBtn.addEventListener('click', exportAudio);
  generateChordsBtn.addEventListener('click', generateChords);
  generateMelodyBtn.addEventListener('click', generateMelody);
}

function togglePlayback() {
  if (isPlaying) {
    stopPlayback();
  } else {
    startPlayback();
  }
}

function startPlayback() {
  isPlaying = true;
  playBtn.textContent = '❚❚';
  // Start audio processing here
}

function stopPlayback() {
  isPlaying = false;
  playBtn.textContent = '▶';
  // Stop audio processing here
}

function updateBPM() {
  currentBPM = parseInt(bpmControl.value);
  bpmValue.textContent = `${currentBPM} BPM`;
}

function updateMasterVolume() {
  // Update master volume in audio context
}

function updateMeter() {
  // Simulate meter movement
  const level = Math.random() * 100;
  masterMeter.style.width = `${level}%`;
  
  // Color based on level
  if (level > 90) {
    masterMeter.style.backgroundColor = '#f44336';
  } else if (level > 70) {
    masterMeter.style.backgroundColor = '#FFC107';
  } else {
    masterMeter.style.backgroundColor = '#4CAF50';
  }
  
  requestAnimationFrame(updateMeter);
}

function newProject() {
  if (confirm('Start a new project? All unsaved changes will be lost.')) {
    tracksContainer.innerHTML = '';
    tracks = [];
    createDefaultTracks();
  }
}

function saveProject() {
  const projectName = prompt('Enter project name:', 'My Project');
  if (projectName) {
    const projectData = {
      name: projectName,
      bpm: currentBPM,
      tracks: tracks
    };
    // In a real app, this would save to local storage or a server
    console.log('Project saved:', projectData);
    alert('Project saved successfully!');
  }
}

function exportAudio() {
  // In a real app, this would render the audio and provide download
  alert('Exporting audio file...');
}

function generateChords() {
  const style = aiStyleSelect.value;
  // In a real app, this would use AI to generate chords
  alert(`Generating ${style} chord progression...`);
}

function generateMelody() {
  const style = aiStyleSelect.value;
  // In a real app, this would use AI to generate melody
  alert(`Generating ${style} melody...`);
}

// Initialize the app
document.addEventListener('DOMContentLoaded', init);